aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/PixelValue.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/core/PixelValue.h')
-rw-r--r--arm_compute/core/PixelValue.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/arm_compute/core/PixelValue.h b/arm_compute/core/PixelValue.h
index 4a07fa6c5d..e237498920 100644
--- a/arm_compute/core/PixelValue.h
+++ b/arm_compute/core/PixelValue.h
@@ -43,7 +43,7 @@ public:
*
* @param[in] v int value.
* @param[in] datatype DataType that @p v have to be stored
* @param[in] qinfo (Optional) QuantizationInfo to apply in case of QASYMM8 datatype to @p v
*/
PixelValue(uint64_t v, DataType datatype, QuantizationInfo qinfo = QuantizationInfo())
: PixelValue()
@@ -68,6 +68,9 @@ public:
case DataType::S16:
value.s16 = static_cast<int16_t>(v);
break;
+ case DataType::QASYMM16:
+ value.u16 = quantize_qasymm16(static_cast<uint16_t>(v), qinfo);
+ break;
case DataType::QSYMM16:
value.s16 = quantize_qsymm16(static_cast<int16_t>(v), qinfo);
break;
@@ -43,7 +43,7 @@ public:
* @param[in] v int value.
* @param[in] datatype DataType that @p v have to be stored
- * @param[in] qinfo (Optional) QuantizationInfo to apply in case of QASYMM8 datatype to @p v
+ * @param[in] qinfo (Optional) QuantizationInfo to apply in case of quantized data types to @p v
*/
PixelValue(uint64_t v, DataType datatype, QuantizationInfo qinfo = QuantizationInfo())